/*
 *   dacpidump3 - Dancer's ACPI monitoring system console debug tool v2
 *   Copyright (C) 2002 Junichi Uekawa
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <stdio.h>
#include "libdanceracpi/libdanceracpi.h"

int main (int ac, char**av)
{
  DACPI_ADAPTER_TYPE adapterstate = dacpi_get_ac_adapter (0);
  int batt_id = 0;

  if (dacpi_obtain_library_api_version() != DACPI_API_VERSION)
    {
      fprintf (stderr, "WARNING: library (%i) and binary (%i) compiled against different DACPI API version\n", 
	       dacpi_obtain_library_api_version(), 
	       DACPI_API_VERSION);
    }
  
  if (!dacpi_check_acpi_support())
    {
      printf ("ACPI is not supported on this system\n");
      return 1;
    }

  printf ("Rate: %li, Capacity: %li / %li\n", 
	  dacpi_get_battery_using(batt_id), 
	  dacpi_get_battery_current(batt_id), 
	  dacpi_get_battery_max(batt_id));
  printf ("Lasts: %f hours, %f%% full \n", 
	  dacpi_get_battery_current(batt_id) / (float)dacpi_get_battery_using(batt_id),
	  (float)dacpi_get_battery_current(batt_id) / (float)dacpi_get_battery_max(batt_id) * 100.0);

  printf ("Current adapter state: %s\n", 
	  adapterstate == DACPI_AC_ERROR ? "Error" : 
	  adapterstate == DACPI_AC_ONLINE ? "On-line" : 
	  "Off-line");
  
  return 0;
}
