/*
 *   dgacpi - Dancer's ACPI monitoring system GTK+ debug tool.
 *   Copyright (C) 2002 Junichi Uekawa
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#define _GNU_SOURCE

#include <stdio.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include <locale.h>
#include <getopt.h>
#include "dgacpi.h"
#include "libdanceracpi/libdanceracpi.h"

static int ac_adapter_id=0;
static int battery_id=1;


gint timeout_command (gpointer data)
{
  dacpi_battery b;
  datastruct * ds = (datastruct * )data;
  int adapterstate = dacpi_get_ac_adapter (ac_adapter_id);
  char * strbuf=NULL;
  float minutes_left, hours_left;
  
  if (dacpi_get_battery (battery_id, &b))
    {
      printf ("Battery does not exist\n");
      exit (1);
    }
  
  
  gtk_progress_configure(GTK_PROGRESS(ds->progress), b.battery_current * 100 /  b.battery_max, 0.0, 100);

  if (b.battery_using) 
    {
      hours_left =  ((float)b.battery_current / (float)b.battery_using);
      minutes_left = (hours_left - (int) hours_left ) * 60.0 ;
  
      asprintf (&strbuf, "%i:%i (%s)", (int)hours_left, 
		(int) minutes_left,
		adapterstate == DACPI_AC_OFFLINE ? "offline" :
		adapterstate == DACPI_AC_ONLINE ? "online" : "");
    }
  else
    {
      asprintf (&strbuf, "MAX (%s)", 
		adapterstate == DACPI_AC_OFFLINE ? "offline" :
		adapterstate == DACPI_AC_ONLINE ? "online" : "");      
    }
  
  gtk_label_set_text (GTK_LABEL(ds->text), strbuf);
  free (strbuf);  
  return 1;  
}

void getoptions(int ac, char**av)
{
  int index_point;
  int c;
  static struct option long_options [] = 
    {
      {"battery", required_argument, 0, 'b'}, 
      {"ac", required_argument, 0, 'a'}, 
      {"help", no_argument, 0, 'h'}, 
      {0,0,0,0}
    };

  while((c = getopt_long (ac, av, "b:a:h", long_options, &index_point)) != -1)
    {
      switch (c)
	{
	case 'b':		/* battery */
	  battery_id = atoi (optarg);
	  break;
	case 'a':		/* AC */
	  ac_adapter_id = atoi (optarg);
	  break;
	case 'h':
	default:
	  printf ("%s\n\n"
		  "Options:\n"
		  "\t--battery ID : specify battery ID\n"
		  "\t--ac ID : specify ac adapter ID\n\n"
		  , av[0]);
	  exit(1);
	  break;	  
	}
    }
}


int main (int ac, char**av)
{
  gint hTimeout;
  datastruct ds;

  /* general initialization. */
  setlocale(LC_TIME, "");

  if (!dacpi_check_acpi_support())
    {
      fprintf (stderr, "ACPI support not detected. Please check /proc/acpi status\n");
      return 1;
    }
  if (dacpi_obtain_library_api_version() != DACPI_API_VERSION)
    {
      fprintf (stderr, "WARNING: library (%i) and binary (%i) compiled against different DACPI API version\n", 
	       dacpi_obtain_library_api_version(), 
	       DACPI_API_VERSION);
    }
  
  gtk_init (&ac, &av);

  getoptions(ac, av);
  
  CreateMainWindow(&ds);
  hTimeout = gtk_timeout_add(10*1000, timeout_command, &ds);
  gtk_main();
  gtk_timeout_remove(hTimeout);
  return 0;
}
